@@ -7,6 +7,7 @@
 #' @param ni Integer vector of population sizes
 #' @return Numeric vector of sampled counts
 #' @export
+#' @keywords internal
 #' @importFrom BiasedUrn rMFNCHypergeo
 biasedUrn_rmfnc <- function(total, odds, ni) {
   total <- as.integer(round(total))
@@ -45,6 +46,7 @@ biasedUrn_rmfnc <- function(total, odds, ni) {
 #' @param log Logical, return log probability
 #' @return The log-probability (if log=1) or probability (if log=0)
 #' @export
+#' @keywords internal
 #' @import nimble
 dmfnchypg <- nimble::nimbleFunction(
   run = function(x = double(1), total = double(0), odds = double(1), 
@@ -104,6 +106,7 @@ dmfnchypg <- nimble::nimbleFunction(
 #' @param ni Vector of category sizes
 #' @return Vector of sampled counts
 #' @export
+#' @keywords internal
 #' @rdname Rmfnchypg_rcall
 Rmfnchypg <- nimble::nimbleRcall(
   prototype = function(total = double(0), odds = double(1), ni = double(1)) {},
@@ -119,6 +122,7 @@ Rmfnchypg <- nimble::nimbleRcall(
 #' @param ni Vector of category sizes
 #' @return Vector of sampled counts
 #' @export
+#' @keywords internal
 #' @rdname rmfnchypg
 rmfnchypg <- nimble::nimbleFunction(
   run = function(n = integer(0), total = double(0), odds = double(1), 
@@ -129,11 +133,10 @@ rmfnchypg <- nimble::nimbleFunction(
 )
 
 #' Register Custom NIMBLE Distributions
-#' 
 #' Registers the custom distributions for use in NIMBLE models.
-#' 
 #' @return Invisible TRUE
 #' @export
+#' @keywords internal
 register_nimble_distributions <- function() {
   if (exists("distributions_registered", envir = .pkg_env) && 
       .pkg_env$distributions_registered) {
@@ -161,7 +164,6 @@ register_nimble_distributions <- function() {
 #'
 #' Returns the NIMBLE code for the Atom-Based Regression Model with mixed-type variables.
 #' Automatically registers custom distributions if not already registered.
-#'
 #' @return A nimbleCode object containing the model specification
 #' @export
 get_abrm_model <- function() {
@@ -530,16 +532,16 @@ get_abrm_model <- function() {
 #' @param nburnin Number of burn-in iterations (default: 30000)
 #' @param nchains Number of MCMC chains (default: 2)
 #' @param thin Thinning interval (default: 10)
+#' @param seed Integer seed for reproducibility. Each chain uses seed+(chain_number-1) (default: NULL)
 #' @param save_plots Logical, whether to save diagnostic plots (default: TRUE)
 #' @param output_dir Directory for saving plots (default: NULL)
-#'
 #' @return List containing MCMC samples, summary, and convergence diagnostics
 #' @export
 #' @import nimble
 #' @importFrom grDevices pdf dev.off
 run_nimble_model <- function(constants, data, inits, sim_metadata = NULL, 
                              model_code, niter = 50000, nburnin = 30000, 
-                             nchains = 2, thin = 10, 
+                             nchains = 2, thin = 10, seed = NULL,
                              save_plots = TRUE, output_dir = NULL) {
   
   register_nimble_distributions()
@@ -548,7 +550,7 @@ run_nimble_model <- function(constants, data, inits, sim_metadata = NULL,
     dir.create(output_dir, showWarnings = FALSE, recursive = TRUE)
   }
   
-  message("\nRunning NIMBLE MCMC...\n")
+  message("Running NIMBLE MCMC...\n")
   
   mcmc.out <- nimble::nimbleMCMC(
     code = model_code,
@@ -558,13 +560,14 @@ run_nimble_model <- function(constants, data, inits, sim_metadata = NULL,
     monitors = c('beta_0_y', 'beta_y'),
     thin = thin,
     niter = niter,
+    setSeed = if(!is.null(seed)) seed + (0:(nchains-1)) else FALSE,
     nburnin = nburnin,
     nchains = nchains,
     summary = TRUE
   )
   
-  message("\nCalculating convergence diagnostics...\n")
-  diagnostics <- check_mcmc_diagnostics(mcmc.out, sim_metadata)
+  message("Calculating convergence diagnostics...\n")
+  diagnostics <- check_mcmc_diagnostics(mcmc.out, sim_metadata, p_x = constants$p_x, p_y = constants$p_y)
   
   print_convergence_summary(diagnostics)
   
@@ -586,7 +589,7 @@ run_nimble_model <- function(constants, data, inits, sim_metadata = NULL,
     print(diagnostics$plots$trace)
     print(diagnostics$plots$density)
     grDevices::dev.off()
-    message("\nDiagnostic plots saved to", plot_file, "\n")
+    message("Diagnostic plots saved to", plot_file, "\n")
   }
   
   mcmc.out$convergence <- diagnostics
